@@ -1,9 +1,10 @@
-module Options (Options (..), parseArgs) where
+module Options (Options (..), Settings (..), parseArgs) where
 
-import Control.Applicative ((<**>))
+import Control.Applicative (Alternative ((<|>)), (<**>))
 import Options.Applicative
   ( Parser,
     execParser,
+    flag',
     fullDesc,
     help,
     helper,
@@ -15,26 +16,34 @@ import Options.Applicative
     switch,
   )
 
-data Options = MkOptions
-  { opVerbose :: Bool,
-    opFilename :: FilePath
+data Settings = MkSettings
+  { seFilename :: FilePath,
+    seVerbose :: Bool
   }
   deriving (Show)
 
+data Options = OpOptions Settings | OpVersion
+
 parseArgs :: IO Options
 parseArgs = execParser (info (parser <**> helper) fullDesc)
 
 parser :: Parser Options
-parser =
-  MkOptions
-    <$> switch
-      ( long "verbose"
-          <> short 'v'
-          <> help "Enable verbose mode"
-      )
-    <*> strOption
+parser = OpOptions <$> settingsParser <|> OpVersion <$ versionParser
+
+versionParser :: Parser Bool
+versionParser = flag' True (long "version" <> short 'V' <> help "Show version")
+
+settingsParser :: Parser Settings
+settingsParser =
+  MkSettings
+    <$> strOption
       ( long "filename"
           <> short 'f'
           <> metavar "FILENAME"
           <> help "Path to the configuration file"
       )
+    <*> switch
+      ( long "verbose"
+          <> short 'v'
+          <> help "Enable verbose mode"
+      )
